@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-invoice-table" "1.1.2"
+(define-package "org-invoice-table" "20250409.402"
   "Invoicing table formatter for org-mode."
   '((emacs "26.1"))
   :url "https://codeberg.org/trevdev/org-invoice-table"
